/*
 * portrait.c - Takes the output of 'spr2pc' with 2x1 X/Y zoom and creates
 *	a new portrait file with the portrait properly rotated and sized.
 *      This is not intended for copyright infringement.
 *
 * Copyright 2000, George Greer <greerga@muc.muohio.edu>
 *
 * Licensed under the GNU General Public License (GPL)
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *   or visit ftp://ftp.gnu.org/pub/gnu/COPYING via the Internet.
 */

#include <stdio.h>
#include <gd.h>

const char *copyright = "portrait.c: Copyright 2000, George Greer <greerga@muc.muohio.edu>";
const char *version = "v0.1 (Build: "__DATE__" "__TIME__")";

#define OFF_X	127
#define OFF_Y	260

void error(const char *why)
{
  perror(why);
  exit(1);
}

int main(int argc, char *argv[])
{
  char *inputfile, *outputfile;
  FILE *ifile, *ofile;
  gdImagePtr src, dst;
  int xi, yi, oclr, nclr;

  if (argc < 3) {
    printf("Usage: %s input-spr2pc-file output-portrait-file\n", argv[0]);
    return 1;
  }

  inputfile = argv[1];
  outputfile = argv[2];

  if (!(ifile = fopen(inputfile, "r")))
    error(inputfile);

  if (!(ofile = fopen(outputfile, "wb")))
    error(outputfile);

  if (!(src = gdImageCreateFromGif(ifile)))
    error("input not a GIF");

  dst = gdImageCreate(32, 48);
  for (yi = 0; yi < 48; yi++)
    for (xi = 0; xi < 32; xi++) {
      oclr = gdImageGetPixel(src, OFF_X - yi, xi + OFF_Y);
      if ((nclr = gdImageColorExact(dst, src->red[oclr], src->green[oclr], src->blue[oclr])) < 0)
        nclr = gdImageColorAllocate(dst, src->red[oclr], src->green[oclr], src->blue[oclr]);
      gdImageSetPixel(dst, xi, yi, nclr);
    }

  gdImageGif(dst, ofile);
  fclose(ofile);
  fclose(ifile);
  return 0;
}
